to_grpc_insert_requests_for_aux_tables

Function to_grpc_insert_requests_for_aux_tables 

pub fn to_grpc_insert_requests_for_aux_tables(
    aux_data: TraceAuxData,
    pipeline: &PipelineWay,
    table_name: &str,
) -> Result<(RowInsertRequests, usize)>
Build insert requests for the auxiliary trace tables derived from accepted spans.

“Aux” here refers to the trace service and trace operation tables, not the main trace span table itself.